==> pulsar-client-all-3.1.1-sources.jar: org/apache/pulsar/shade/org/glassfish/jersey/internal/inject/ParamConverterConfigurator.java <==
/*
 * Copyright (c) 2017, 2021 Oracle and/or its affiliates. All rights reserved.
 * Copyright (c) 2018 Payara Foundation and/or its affiliates.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.pulsar.shade.org.glassfish.jersey.internal.inject;

import org.apache.pulsar.shade.javax.ws.rs.ext.ParamConverterProvider;

import org.apache.pulsar.shade.org.glassfish.jersey.internal.BootstrapBag;
import org.apache.pulsar.shade.org.glassfish.jersey.internal.BootstrapConfigurator;

/**
 * Configurator which initializes and register {@link ParamConverters.AggregatedProvider} instances into {@link InjectionManager}.
 *
 * @author Petr Bouda
 */
public class ParamConverterConfigurator implements BootstrapConfigurator {

    @Override
    public void init(InjectionManager injectionManager, BootstrapBag bootstrapBag) {
        InstanceBinding<ParamConverters.AggregatedProvider> aggregatedConverters =
                Bindings.service(new ParamConverters.AggregatedProvider())
                    .to(ParamConverterProvider.class);
        injectionManager.register(aggregatedConverters);
    }
}

==> pulsar-client-all-4.0.5-sources.jar: org/apache/pulsar/shade/org/glassfish/jersey/internal/inject/ParamConverterConfigurator.java <==
/*
 * Copyright (c) 2017, 2021 Oracle and/or its affiliates. All rights reserved.
 * Copyright (c) 2018 Payara Foundation and/or its affiliates.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package org.apache.pulsar.shade.org.glassfish.jersey.internal.inject;

import org.apache.pulsar.shade.javax.ws.rs.ext.ParamConverterProvider;

import org.apache.pulsar.shade.org.glassfish.jersey.internal.BootstrapBag;
import org.apache.pulsar.shade.org.glassfish.jersey.internal.BootstrapConfigurator;

/**
 * Configurator which initializes and register {@link ParamConverters.AggregatedProvider} instances into {@link InjectionManager}.
 *
 * @author Petr Bouda
 */
public class ParamConverterConfigurator implements BootstrapConfigurator {

    @Override
    public void init(InjectionManager injectionManager, BootstrapBag bootstrapBag) {
        final ClassBinding<ParamConverters.AggregatedProvider> aggregatedConverters =
                Bindings.service(ParamConverters.AggregatedProvider.class)
                    .to(ParamConverterProvider.class);
        injectionManager.register(aggregatedConverters);
    }
}
